# DragonTide
Continuous Command Recognition (CCR) for [Dragonfly](https://dragonfly2.readthedocs.io/en/latest/index.html)

# Project Origins
This project was forked from [dragonfluid](https://github.com/chajadan/dragonfluid). I have heard from others in the Dragonfly community that the original author is deceased, so I decided the best way forward for me would be to fork it and maintain a new version myself. 

I've renamed the project to DragonTide to distinguish it from the original version of dragonfluid.

I'd like to express my appreciation to [Charles J. Daniels](https://github.com/chajadan) for his excellent work developing this package, and I'd also like to express my heartfelt condolences to anyone who knew and loved him and is grieving his passing.

# Developing
```python
pip install -e '.[dev]'
```